TOOL.Category = "Construction"
TOOL.Name = "Weapon Cache Creator"

TOOL.ClientConVar[ "weapon" ] = "weapon_ak47"
TOOL.ClientConVar[ "weaponname" ] = "Gun"
TOOL.ClientConVar[ "model" ] = "models/items/item_item_crate.mdl"
TOOL.ClientConVar[ "ammo1" ] = "none"
TOOL.ClientConVar[ "ammo2" ] = "none"
TOOL.ClientConVar[ "ammo3" ] = "none"
TOOL.ClientConVar[ "ammo1amt" ] = 0
TOOL.ClientConVar[ "ammo2amt" ] = 0
TOOL.ClientConVar[ "ammo3amt" ] = 0
TOOL.ClientConVar[ "radar" ] = 0

if CLIENT then
	language.Add( "Tool_cache_creator_name", "Weapon Cache Creator" )
	language.Add( "Tool_cache_creator_desc", "Creates weapon caches with selectable weapon and ammo" )
	language.Add( "Tool_cache_creator_0", "Left click to place cache" )
	language.Add( "Undone_Weapon Cache", "Undone Weapon Cache" )
end

function TOOL:LeftClick( tr )
	if not tr.Hit then
		return false
	end
	
	if CLIENT then
		return true
	end
	
	local weapon, wname, model, ammo1, ammo2, ammo3, amt1, amt2, amt3, ent, radar
	
	weapon = self:GetClientInfo( "weapon" )
	wname = self:GetClientInfo( "weaponname" )
	model = self:GetClientInfo( "model" )
	ammo1 = self:GetClientInfo( "ammo1" )
	ammo2 = self:GetClientInfo( "ammo2" )
	ammo3 = self:GetClientInfo( "ammo3" )
	amt1 = self:GetClientNumber( "ammo1amt" )
	amt2 = self:GetClientNumber( "ammo2amt" )
	amt3 = self:GetClientNumber( "ammo3amt" )
	radar = self:GetClientNumber( "radar" ) == 1
	
	amt1 = math.Clamp( amt1, 0, 100 )
	amt2 = math.Clamp( amt2, 0, 100 )
	amt3 = math.Clamp( amt3, 0, 100 )
	
	if not weapons.GetStored( weapon ) then
		self:GetOwner( ):ChatPrint( "Only scripted weapons are permitted" )
		return false
	end
	
	if not util.IsValidModel( model ) then
		self:GetOwner( ):ChatPrint( "Only valid models are permitted" )
		return false
	end
	
	ent = ents.Create( "weapon_cache" )
	
	ent:Create( model, Vector( tr.HitPos.x, tr.HitPos.y, tr.HitPos.z ), radar, {
		Weapon = weapon,
		WeaponName = wname,
		Ammo = {
			One = {
				Type = ammo1,
				Count = amt1,
			},
			Two = {
				Type = ammo2,
				Count = amt2,
			},
			Three = {
				Type = ammo3,
				Count = amt3
			}
		},
	} )
	
	ent:Spawn( )
	
	undo.Create( "Weapon Cache" )
		undo.AddEntity( ent )
		undo.SetPlayer( self:GetOwner( ) )
	undo.Finish( )
	
	DoPropSpawnedEffect( ent )
	
	return true
end

function TOOL.BuildCPanel( pnl )
	local t, k, v, ammo, cbo1, cbo2, cbo3, radar, amt1, amt2, amt3, weps, wepname, radar, models
	t = { }
	
	cbo1 = vgui.Create( "DMultiChoice" )
	cbo2 = vgui.Create( "DMultiChoice" )
	cbo3 = vgui.Create( "DMultiChoice" )
	
	amt1 = vgui.Create( "DNumSlider" )
	amt2 = vgui.Create( "DNumSlider" )
	amt3 = vgui.Create( "DNumSlider" )
	
	weps = vgui.Create( "DMultiChoice" )
	
	wepname = vgui.Create( "DTextEntry" )
	
	radar = vgui.Create( "DCheckBoxLabel" )
	
	models = vgui.Create( "PropSelect" )
	
	weps:SetConVar( "cache_creator_weapon" )
	
	cbo1:SetConVar( "cache_creator_ammo1" )
	cbo2:SetConVar( "cache_creator_ammo2" )
	cbo3:SetConVar( "cache_creator_ammo3" )
	
	amt1:SetConVar( "cache_creator_ammo1amt" )
	amt2:SetConVar( "cache_creator_ammo2amt" )
	amt3:SetConVar( "cache_creator_ammo3amt" )
	
	amt1:SetDecimals( 0 )
	amt2:SetDecimals( 0 )
	amt3:SetDecimals( 0 )
	
	amt1:SetText( "Ammo of type 1" )
	amt2:SetText( "Ammo of type 2" )
	amt3:SetText( "Ammo of type 3" )
	
	amt1:SetMin( 0 )
	amt2:SetMin( 0 )
	amt3:SetMin( 0 )
	
	amt1:SetMax( 100 )
	amt2:SetMax( 100 )
	amt3:SetMax( 100 )
	
	wepname:SetConVar( "cache_creator_weaponname" )
	
	radar:SetText( "Attach Radar Beacon" )
	radar:SetConVar( "cache_creator_radar" )
	
	ammo = { "None", "AR2", "AlyxGun", "Pistol", "SMG1", "357", "XBowBolt", "Buckshot", "RPG_Round", "SMG1_Grenade", "SniperRound", "SniperPenetratedRound", "Grenade", "Thumper", "Gravity", "Battery", "GaussEneregy", "CombineCannon", "AirboatGun", "StriderMinigun", "HelicopterGun", "AR2AltFire", "Slam" }	
	
	for k, v in ipairs( weapons.GetList( ) ) do
		if v.Spawnable or v.AdminSpawnable then
			weps:AddChoice( v.Classname )
		end
	end
	
	models.Label:SetText( "Cache Model" )
	models:SetConVar( "cache_creator_model" )
	
	for k, v in ipairs( list.Get( "WeaponCacheModels" ) ) do
		models:AddModel( v, { } )
	end
	
	for k, v in ipairs( ammo ) do
		cbo1:AddChoice( v )
		cbo2:AddChoice( v )
		cbo3:AddChoice( v )
	end

	pnl:AddControl( "Header", { Text = "Weapon Cache Creator", Description = "Customize your weapon cache" } )	
	pnl:AddItem( Label( "Displayed Weapon Name" ) )
	pnl:AddItem( wepname )
	pnl:AddItem( Label( "Weapon Class" ) )
	pnl:AddItem( weps )
	pnl:AddItem( models )
	pnl:AddItem( Label( "Ammo Types" ) )
	pnl:AddItem( cbo1 )
	pnl:AddItem( cbo2 )
	pnl:AddItem( cbo3 )
	pnl:AddItem( Label( "Ammo Amounts" ) )
	pnl:AddItem( amt1 )
	pnl:AddItem( amt2 )
	pnl:AddItem( amt3 )
	pnl:AddItem( radar )
end